@@ -178,7 +178,10 @@ public abstract class AbstractLauncher implements Serializable {
 		IProblem problem = reader.parseInstance(problemname);
 		log("... done. Wall clock time " //$NON-NLS-1$
 				+ (System.currentTimeMillis() - beginTime) / 1000.0 + "s."); //$NON-NLS-1$
-		log("#vars     " + problem.nVars()); //$NON-NLS-1$
+		log("declared #vars     " + problem.nVars()); //$NON-NLS-1$
+		if (solver.nVars() < solver.realNumberOfVariables()) {
+			log("internal #vars     " + solver.realNumberOfVariables()); //$NON-NLS-1$
+		}
 		log("#constraints  " + problem.nConstraints()); //$NON-NLS-1$
 		problem.printInfos(out, COMMENT_PREFIX);
 		return problem;
@@ -203,9 +206,9 @@ public abstract class AbstractLauncher implements Serializable {
 				return;
 			}
 			beginTime = System.currentTimeMillis();
-			IProblem problem = readProblem(instanceName);
+			readProblem(instanceName);
 			try {
-				solve(problem);
+				solve(solver);
 			} catch (TimeoutException e) {
 				log("timeout"); //$NON-NLS-1$
 			}
