@@ -27,6 +27,8 @@
  *******************************************************************************/
 package org.sat4j.core;
 
+import java.util.ArrayList;
+import java.util.List;
 import java.util.NoSuchElementException;
 
 import org.sat4j.specs.IVecInt;
@@ -70,8 +72,8 @@ public final class VecInt implements IVecInt {
 	public static final IVecInt EMPTY = new IVecInt() {
 
 		/**
-         * 
-         */
+		 * 
+		 */
 		private static final long serialVersionUID = 1L;
 
 		public int size() {
@@ -200,6 +202,14 @@ public final class VecInt implements IVecInt {
 			return "[]";
 		}
 
+		public void moveTo(int sourceStartingIndex, int[] dest) {
+			throw new UnsupportedOperationException();
+		}
+
+		public IVecInt[] subset(int cardinal) {
+			return new IVecInt[0];
+		};
+
 	};
 
 	public VecInt() {
@@ -405,6 +415,12 @@ public final class VecInt implements IVecInt {
 		nbelem = 0;
 	}
 
+	public void moveTo(int sourceStartingIndex, int[] dest) {
+		System.arraycopy(myarray, sourceStartingIndex, dest, 0, nbelem
+				- sourceStartingIndex);
+		nbelem = 0;
+	}
+
 	/**
 	 * Insert an element at the very begining of the vector. The former first
 	 * element is appended to the end of the vector in order to have a constant
@@ -434,7 +450,7 @@ public final class VecInt implements IVecInt {
 		for (; myarray[j] != elem; j++) {
 			assert j < size();
 		}
-		System.arraycopy(myarray, j + 1, myarray, j, size() - j);
+		System.arraycopy(myarray, j + 1, myarray, j, size() - j - 1);
 		pop();
 	}
 
@@ -653,4 +669,49 @@ public final class VecInt implements IVecInt {
 	public int[] toArray() {
 		return myarray;
 	}
+
+	/**
+	 * @since 2.3.1
+	 * @author sroussel
+	 */
+	public IVecInt[] subset(int cardinal) {
+		List<IVecInt> liste = new ArrayList<IVecInt>();
+
+		IVecInt[] result;
+
+		if (cardinal == 1) {
+			result = new VecInt[this.size()];
+			for (int i = 0; i < this.size(); i++) {
+				result[i] = new VecInt(new int[] { this.get(i) });
+			}
+			return result;
+		}
+
+		if (this.size() == 0) {
+			result = new VecInt[0];
+			return result;
+		}
+
+		VecInt subVec = new VecInt();
+		VecInt newVec;
+		this.copyTo(subVec);
+		subVec.remove(this.get(0));
+
+		for (IVecInt vecWithFirst : subVec.subset(cardinal - 1)) {
+			newVec = new VecInt();
+			vecWithFirst.copyTo(newVec);
+			newVec.insertFirst(this.get(0));
+			liste.add(newVec);
+		}
+
+		for (IVecInt vecWithoutFirst : subVec.subset(cardinal)) {
+			liste.add(vecWithoutFirst);
+		}
+
+		result = new VecInt[liste.size()];
+		for (int i = 0; i < liste.size(); i++) {
+			result[i] = liste.get(i);
+		}
+		return result;
+	}
 }
