@@ -19,9 +19,9 @@
 package org.sat4j.minisat;
 
 import org.sat4j.core.ASolverFactory;
-import org.sat4j.minisat.constraints.ClausalDataStructureCBWL;
 import org.sat4j.minisat.constraints.MixedDataStructureDanielHT;
 import org.sat4j.minisat.constraints.MixedDataStructureDanielWL;
+import org.sat4j.minisat.constraints.MixedDataStructureSingleWL;
 import org.sat4j.minisat.core.DataStructureFactory;
 import org.sat4j.minisat.core.IOrder;
 import org.sat4j.minisat.core.SearchParams;
@@ -32,6 +32,7 @@ import org.sat4j.minisat.learning.NoLearningButHeuristics;
 import org.sat4j.minisat.learning.PercentLengthLearning;
 import org.sat4j.minisat.orders.PhaseCachingAutoEraseStrategy;
 import org.sat4j.minisat.orders.PureOrder;
+import org.sat4j.minisat.orders.RSATLastLearnedClausesPhaseSelectionStrategy;
 import org.sat4j.minisat.orders.RSATPhaseSelectionStrategy;
 import org.sat4j.minisat.orders.RandomWalkDecorator;
 import org.sat4j.minisat.orders.VarOrderHeap;
@@ -39,8 +40,6 @@ import org.sat4j.minisat.restarts.ArminRestarts;
 import org.sat4j.minisat.restarts.LubyRestarts;
 import org.sat4j.minisat.restarts.MiniSATRestarts;
 import org.sat4j.minisat.restarts.NoRestarts;
-import org.sat4j.minisat.uip.DecisionUIP;
-import org.sat4j.minisat.uip.FirstUIP;
 import org.sat4j.opt.MinOneDecorator;
 import org.sat4j.specs.ISolver;
 import org.sat4j.tools.DimacsOutputSolver;
@@ -124,7 +123,7 @@ public final class SolverFactory extends ASolverFactory<ISolver> {
 
 	public static Solver<DataStructureFactory> newMiniLearningHeapRsatExpSimpLuby() {
 		Solver<DataStructureFactory> solver = newMiniLearningHeapRsatExpSimp();
-		solver.setRestartStrategy(new LubyRestarts());
+		solver.setRestartStrategy(new LubyRestarts(512));
 		return solver;
 	}
 
@@ -132,7 +131,7 @@ public final class SolverFactory extends ASolverFactory<ISolver> {
 			DataStructureFactory dsf) {
 		MiniSATLearning<DataStructureFactory> learning = new MiniSATLearning<DataStructureFactory>();
 		Solver<DataStructureFactory> solver = new Solver<DataStructureFactory>(
-				new FirstUIP(), learning, dsf, new VarOrderHeap(
+				learning, dsf, new VarOrderHeap(
 						new RSATPhaseSelectionStrategy()), new ArminRestarts());
 		solver.setSearchParams(new SearchParams(1.1, 100));
 		learning.setSolver(solver);
@@ -147,7 +146,7 @@ public final class SolverFactory extends ASolverFactory<ISolver> {
 	public static Solver<DataStructureFactory> newGreedySolver() {
 		MiniSATLearning<DataStructureFactory> learning = new MiniSATLearning<DataStructureFactory>();
 		Solver<DataStructureFactory> solver = new Solver<DataStructureFactory>(
-				new FirstUIP(), learning, new MixedDataStructureDanielWL(),
+				learning, new MixedDataStructureDanielWL(),
 				new RandomWalkDecorator(new VarOrderHeap(
 						new RSATPhaseSelectionStrategy())), new NoRestarts());
 		// solver.setSearchParams(new SearchParams(1.1, 100));
@@ -165,6 +164,16 @@ public final class SolverFactory extends ASolverFactory<ISolver> {
 		return solver;
 	}
 
+	/**
+	 * @since 2.2.3
+	 */
+	public static Solver<DataStructureFactory> newDefaultMS21PhaseSaving() {
+		Solver<DataStructureFactory> solver = newBestWL();
+		solver.setOrder(new VarOrderHeap(
+				new RSATLastLearnedClausesPhaseSelectionStrategy()));
+		return solver;
+	}
+
 	/**
 	 * @since 2.1
 	 */
@@ -180,6 +189,29 @@ public final class SolverFactory extends ASolverFactory<ISolver> {
 		return newBestCurrentSolverConfiguration(new MixedDataStructureDanielHT());
 	}
 
+	/**
+	 * 
+	 * @since 2.2
+	 */
+	public static Solver<DataStructureFactory> newBestSingleWL() {
+		return newBestCurrentSolverConfiguration(new MixedDataStructureSingleWL());
+	}
+
+	/**
+	 * 
+	 * @since 2.2
+	 */
+	public static Solver<DataStructureFactory> newBest17() {
+		Solver<DataStructureFactory> solver = newBestCurrentSolverConfiguration(new MixedDataStructureSingleWL());
+		solver.setSimplifier(solver.EXPENSIVE_SIMPLIFICATION_WLONLY);
+		solver.setLearnedConstraintsDeletionStrategy(solver.memory_based);
+		LimitedLearning<DataStructureFactory> learning = new PercentLengthLearning<DataStructureFactory>(
+				10);
+		solver.setLearner(learning);
+		learning.setSolver(solver);
+		return solver;
+	}
+
 	/**
 	 * @since 2.1
 	 */
@@ -214,14 +246,6 @@ public final class SolverFactory extends ASolverFactory<ISolver> {
 				new PureOrder());
 	}
 
-	/**
-	 * @return a default minilearning SAT solver choosing periodically to branch
-	 *         on literal "pure in the original set of clauses" if any.
-	 */
-	public static Solver<DataStructureFactory> newMiniLearningCBWLPure() {
-		return newMiniLearning(new ClausalDataStructureCBWL(), new PureOrder());
-	}
-
 	/**
 	 * @param dsf
 	 *            the data structure factory used to represent literals and
@@ -239,7 +263,7 @@ public final class SolverFactory extends ASolverFactory<ISolver> {
 		// PercentLengthLearning<DataStructureFactory>(10);
 		MiniSATLearning<DataStructureFactory> learning = new MiniSATLearning<DataStructureFactory>();
 		Solver<DataStructureFactory> solver = new Solver<DataStructureFactory>(
-				new FirstUIP(), learning, dsf, order, new MiniSATRestarts());
+				learning, dsf, order, new MiniSATRestarts());
 		learning.setSolver(solver);
 		return solver;
 	}
@@ -251,8 +275,8 @@ public final class SolverFactory extends ASolverFactory<ISolver> {
 		LimitedLearning<DataStructureFactory> learning = new PercentLengthLearning<DataStructureFactory>(
 				10);
 		Solver<DataStructureFactory> solver = new Solver<DataStructureFactory>(
-				new FirstUIP(), learning, new MixedDataStructureDanielWL(),
-				new SearchParams(Integer.MAX_VALUE), new VarOrderHeap(),
+				learning, new MixedDataStructureDanielWL(), new SearchParams(
+						Integer.MAX_VALUE), new VarOrderHeap(),
 				new MiniSATRestarts());
 		learning.setSolver(solver);
 		solver.setSimplifier(solver.SIMPLE_SIMPLIFICATION);
@@ -266,9 +290,8 @@ public final class SolverFactory extends ASolverFactory<ISolver> {
 		LimitedLearning<DataStructureFactory> learning = new PercentLengthLearning<DataStructureFactory>(
 				10);
 		Solver<DataStructureFactory> solver = new Solver<DataStructureFactory>(
-				new FirstUIP(), learning, new MixedDataStructureDanielWL(),
-				new SearchParams(1000), new VarOrderHeap(),
-				new MiniSATRestarts());
+				learning, new MixedDataStructureDanielWL(), new SearchParams(
+						1000), new VarOrderHeap(), new MiniSATRestarts());
 		learning.setSolver(solver);
 		solver.setSimplifier(solver.SIMPLE_SIMPLIFICATION);
 		return solver;
@@ -301,21 +324,7 @@ public final class SolverFactory extends ASolverFactory<ISolver> {
 			DataStructureFactory dsf) {
 		MiniSATLearning<DataStructureFactory> learning = new MiniSATLearning<DataStructureFactory>();
 		Solver<DataStructureFactory> solver = new Solver<DataStructureFactory>(
-				new FirstUIP(), learning, dsf, new VarOrderHeap(),
-				new MiniSATRestarts());
-		learning.setDataStructureFactory(solver.getDSFactory());
-		learning.setVarActivityListener(solver);
-		return solver;
-	}
-
-	/**
-	 * @return MiniSAT with decision UIP clause generator.
-	 */
-	public static Solver<MixedDataStructureDanielWL> newRelsat() {
-		MiniSATLearning<MixedDataStructureDanielWL> learning = new MiniSATLearning<MixedDataStructureDanielWL>();
-		Solver<MixedDataStructureDanielWL> solver = new Solver<MixedDataStructureDanielWL>(
-				new DecisionUIP(), learning, new MixedDataStructureDanielWL(),
-				new VarOrderHeap(), new MiniSATRestarts());
+				learning, dsf, new VarOrderHeap(), new MiniSATRestarts());
 		learning.setDataStructureFactory(solver.getDSFactory());
 		learning.setVarActivityListener(solver);
 		return solver;
@@ -328,8 +337,8 @@ public final class SolverFactory extends ASolverFactory<ISolver> {
 	public static Solver<MixedDataStructureDanielWL> newBackjumping() {
 		NoLearningButHeuristics<MixedDataStructureDanielWL> learning = new NoLearningButHeuristics<MixedDataStructureDanielWL>();
 		Solver<MixedDataStructureDanielWL> solver = new Solver<MixedDataStructureDanielWL>(
-				new FirstUIP(), learning, new MixedDataStructureDanielWL(),
-				new VarOrderHeap(), new MiniSATRestarts());
+				learning, new MixedDataStructureDanielWL(), new VarOrderHeap(),
+				new MiniSATRestarts());
 		learning.setVarActivityListener(solver);
 		return solver;
 	}
