@@ -84,7 +84,7 @@ public class UnitClause implements Constr {
 	}
 
 	public boolean simplify() {
-		throw new UnsupportedOperationException();
+		return false;
 	}
 
 	public boolean propagate(UnitPropagationListener s, int p) {
@@ -98,7 +98,7 @@ public class UnitClause implements Constr {
 	}
 
 	public boolean learnt() {
-		throw new UnsupportedOperationException();
+		return false;
 	}
 
 	public int size() {
@@ -113,4 +113,8 @@ public class UnitClause implements Constr {
 	public String toString() {
 		return Lits.toString(literal);
 	}
+
+	public boolean canBePropagatedMultipleTimes() {
+		return false;
+	}
 }
