@@ -63,6 +63,7 @@ import java.util.Map;
 import java.util.Timer;
 import java.util.TimerTask;
 
+import org.sat4j.core.ConstrGroup;
 import org.sat4j.core.Vec;
 import org.sat4j.core.VecInt;
 import org.sat4j.specs.ContradictionException;
@@ -174,13 +175,14 @@ public class Solver<D extends DataStructureFactory> implements ISolver,
 	private boolean verbose = false;
 
 	private String prefix = "c ";
+	private int declaredMaxVarId = 0;
 
 	protected IVecInt dimacs2internal(IVecInt in) {
 		__dimacs_out.clear();
 		__dimacs_out.ensure(in.size());
 		int p;
 		for (int i = 0; i < in.size(); i++) {
-		    p = in.get(i);
+			p = in.get(i);
 			if (p == 0) {
 				throw new IllegalArgumentException(
 						"0 is not a valid variable identifier");
@@ -190,6 +192,13 @@ public class Solver<D extends DataStructureFactory> implements ISolver,
 		return __dimacs_out;
 	}
 
+	/*
+	 * @since 2.3.1
+	 */
+	public void registerLiteral(int p) {
+		voc.getFromPool(p);
+	}
+
 	/**
 	 * creates a Solver without LearningListener. A learningListener must be
 	 * added to the solver, else it won't backtrack!!! A data structure factory
@@ -286,6 +295,16 @@ public class Solver<D extends DataStructureFactory> implements ISolver,
 
 	public void expireTimeout() {
 		undertimeout = false;
+		if (timeBasedTimeout) {
+			if (timer != null) {
+				timer.cancel();
+				timer = null;
+			}
+		} else {
+			if (conflictCount != null) {
+				conflictCount = null;
+			}
+		}
 	}
 
 	protected int nAssigns() {
@@ -293,7 +312,7 @@ public class Solver<D extends DataStructureFactory> implements ISolver,
 	}
 
 	public int nConstraints() {
-		return constrs.size() + trail.size();
+		return constrs.size();
 	}
 
 	public void learn(Constr c) {
@@ -326,7 +345,8 @@ public class Solver<D extends DataStructureFactory> implements ISolver,
 
 	public int newVar(int howmany) {
 		voc.ensurePool(howmany);
-		return voc.nVars();
+		declaredMaxVarId = howmany;
+		return howmany;
 	}
 
 	public IConstr addClause(IVecInt literals) throws ContradictionException {
@@ -392,6 +412,14 @@ public class Solver<D extends DataStructureFactory> implements ISolver,
 		return addConstr(dsfactory.createCardinalityConstraint(vlits, degree));
 	}
 
+	public IConstr addExactly(IVecInt literals, int n)
+			throws ContradictionException {
+		ConstrGroup group = new ConstrGroup(false);
+		group.add(addAtMost(literals, n));
+		group.add(addAtLeast(literals, n));
+		return group;
+	}
+
 	@SuppressWarnings("unchecked")
 	public boolean simplifyDB() {
 		// Simplifie la base de clauses apres la premiere propagation des
@@ -495,30 +523,34 @@ public class Solver<D extends DataStructureFactory> implements ISolver,
 		outLearnt.push(ILits.UNDEFINED);
 		// reserve de la place pour le litteral falsifie
 		int outBtlevel = 0;
+		IConstr prevConfl = null;
 
 		do {
 			preason.clear();
 			assert confl != null;
-			confl.calcReason(p, preason);
-			learnedConstraintsDeletionStrategy.onConflictAnalysis(confl);
-			// Trace reason for p
-			for (int j = 0; j < preason.size(); j++) {
-				int q = preason.get(j);
-				order.updateVar(q);
-				if (!seen[q >> 1]) {
-					seen[q >> 1] = true;
-					if (voc.getLevel(q) == decisionLevel()) {
-						counter++;
-						order.updateVarAtDecisionLevel(q);
-					} else if (voc.getLevel(q) > 0) {
-						// only literals assigned after decision level 0 part of
-						// the explanation
-						outLearnt.push(q ^ 1);
-						outBtlevel = Math.max(outBtlevel, voc.getLevel(q));
+			if (prevConfl != confl) {
+				confl.calcReason(p, preason);
+				learnedConstraintsDeletionStrategy.onConflictAnalysis(confl);
+				// Trace reason for p
+				for (int j = 0; j < preason.size(); j++) {
+					int q = preason.get(j);
+					order.updateVar(q);
+					if (!seen[q >> 1]) {
+						seen[q >> 1] = true;
+						if (voc.getLevel(q) == decisionLevel()) {
+							counter++;
+							order.updateVarAtDecisionLevel(q);
+						} else if (voc.getLevel(q) > 0) {
+							// only literals assigned after decision level 0
+							// part of
+							// the explanation
+							outLearnt.push(q ^ 1);
+							outBtlevel = Math.max(outBtlevel, voc.getLevel(q));
+						}
 					}
 				}
 			}
-
+			prevConfl = confl;
 			// select next reason to look at
 			do {
 				p = trail.last();
@@ -559,7 +591,7 @@ public class Solver<D extends DataStructureFactory> implements ISolver,
 		if (assumps.size() == 0) {
 			return null;
 		}
-		if (trailLim.last() == trail.size()) {
+		while (!trailLim.isEmpty() && trailLim.last() == trail.size()) {
 			// conflict detected when assuming a value
 			trailLim.pop();
 		}
@@ -583,15 +615,14 @@ public class Solver<D extends DataStructureFactory> implements ISolver,
 		}
 
 		int p = ILits.UNDEFINED;
-		while (confl == null && trail.size() > 0) {
+		while (confl == null && trail.size() > 0 && trailLim.size() > 0) {
 			p = trail.last();
 			confl = voc.getReason(p);
 			undoOne();
-			if (confl == null && trailLim.size() > 0
-					&& p == (conflictingLiteral ^ 1)) {
+			if (confl == null && p == (conflictingLiteral ^ 1)) {
 				outLearnt.push(toDimacs(p));
 			}
-			if (trailLim.size() > 0 && trail.size() <= trailLim.last()) {
+			if (trail.size() <= trailLim.last()) {
 				trailLim.pop();
 			}
 		}
@@ -755,19 +786,22 @@ public class Solver<D extends DataStructureFactory> implements ISolver,
 
 	// Taken from MiniSAT 1.14: Simplify conflict clause (a little):
 	private void simpleSimplification(IVecInt conflictToReduce) {
-		int i, j;
+		int i, j, p;
 		final boolean[] seen = mseen;
+		IConstr r;
 		for (i = j = 1; i < conflictToReduce.size(); i++) {
-			IConstr r = voc.getReason(conflictToReduce.get(i));
-			if (r == null) {
+			r = voc.getReason(conflictToReduce.get(i));
+			if (r == null || r.canBePropagatedMultipleTimes()) {
 				conflictToReduce.moveTo(j++, i);
 			} else {
-				for (int k = 0; k < r.size(); k++)
-					if (voc.isFalsified(r.get(k)) && !seen[r.get(k) >> 1]
-							&& (voc.getLevel(r.get(k)) != 0)) {
+				for (int k = 0; k < r.size(); k++) {
+					p = r.get(k);
+					if (!seen[p >> 1] && voc.isFalsified(p)
+							&& (voc.getLevel(p) != 0)) {
 						conflictToReduce.moveTo(j++, i);
 						break;
 					}
+				}
 			}
 		}
 		conflictToReduce.shrink(i - j);
@@ -811,9 +845,15 @@ public class Solver<D extends DataStructureFactory> implements ISolver,
 			assert lvoc.getReason(q) != null;
 			Constr c = lvoc.getReason(q);
 			lanalyzestack.pop();
+			if (c.canBePropagatedMultipleTimes()) {
+				for (int j = top; j < lanalyzetoclear.size(); j++)
+					seen[lanalyzetoclear.get(j) >> 1] = false;
+				lanalyzetoclear.shrink(lanalyzetoclear.size() - top);
+				return false;
+			}
 			for (int i = 0; i < c.size(); i++) {
 				int l = c.get(i);
-				if (lvoc.isFalsified(l) && !seen[var(l)]
+				if (!seen[var(l)] && lvoc.isFalsified(l)
 						&& lvoc.getLevel(l) != 0) {
 					if (lvoc.getReason(l) == null) {
 						for (int j = top; j < lanalyzetoclear.size(); j++)
@@ -826,6 +866,7 @@ public class Solver<D extends DataStructureFactory> implements ISolver,
 					lanalyzetoclear.push(l);
 				}
 			}
+
 		}
 
 		return true;
@@ -1004,6 +1045,7 @@ public class Solver<D extends DataStructureFactory> implements ISolver,
 	public boolean assume(int p) {
 		// Precondition: assume propagation queue is empty
 		assert trail.size() == qhead;
+		assert !trailLim.contains(trail.size());
 		trailLim.push(trail.size());
 		return enqueue(p);
 	}
@@ -1031,7 +1073,7 @@ public class Solver<D extends DataStructureFactory> implements ISolver,
 			learnedLiterals.push(trail.last());
 			undoOne();
 		}
-		qhead = trail.size();
+		// qhead = 0;
 		// learnedLiterals = 0;
 	}
 
@@ -1049,7 +1091,7 @@ public class Solver<D extends DataStructureFactory> implements ISolver,
 
 	private final Pair analysisResult = new Pair();
 
-	private boolean[] fullmodel;
+	private boolean[] userbooleanmodel;
 
 	private IVecInt unsatExplanationInTermsOfAssumptions;
 
@@ -1114,7 +1156,7 @@ public class Solver<D extends DataStructureFactory> implements ISolver,
 				conflictCount.newConflict();
 
 				if (decisionLevel() == rootLevel) {
-					// on est a la racine, la formule est inconsistante
+					// conflict at root level, the formula is inconsistent
 					unsatExplanationInTermsOfAssumptions = analyzeFinalConflictInTermsOfAssumptions(
 							confl, assumps, ILits.UNDEFINED);
 					return Lbool.FALSE;
@@ -1152,28 +1194,44 @@ public class Solver<D extends DataStructureFactory> implements ISolver,
 	private final IVecInt implied = new VecInt();
 	private final IVecInt decisions = new VecInt();
 
+	private int[] fullmodel;
+
 	/**
      * 
      */
 	void modelFound() {
-		model = new int[trail.size()];
-		fullmodel = new boolean[nVars()];
-		int index = 0;
-		for (int i = 1; i <= voc.nVars(); i++) {
+		IVecInt tempmodel = new VecInt(nVars());
+		userbooleanmodel = new boolean[realNumberOfVariables()];
+		fullmodel = null;
+		for (int i = 1; i <= nVars(); i++) {
 			if (voc.belongsToPool(i)) {
 				int p = voc.getFromPool(i);
 				if (!voc.isUnassigned(p)) {
-					model[index++] = voc.isSatisfied(p) ? i : -i;
-					fullmodel[i - 1] = voc.isSatisfied(p);
+					tempmodel.push(voc.isSatisfied(p) ? i : -i);
+					userbooleanmodel[i - 1] = voc.isSatisfied(p);
 					if (voc.getReason(p) == null) {
-						decisions.push(model[index - 1]);
+						decisions.push(tempmodel.last());
 					} else {
-						implied.push(model[index - 1]);
+						implied.push(tempmodel.last());
 					}
 				}
 			}
 		}
-		assert index == model.length;
+		model = new int[tempmodel.size()];
+		tempmodel.copyTo(model);
+		if (realNumberOfVariables() > nVars()) {
+			for (int i = nVars() + 1; i <= realNumberOfVariables(); i++) {
+				if (voc.belongsToPool(i)) {
+					int p = voc.getFromPool(i);
+					if (!voc.isUnassigned(p)) {
+						tempmodel.push(voc.isSatisfied(p) ? i : -i);
+						userbooleanmodel[i - 1] = voc.isSatisfied(p);
+					}
+				}
+			}
+			fullmodel = new int[tempmodel.size()];
+			tempmodel.moveTo(fullmodel);
+		}
 		cancelUntil(rootLevel);
 	}
 
@@ -1208,15 +1266,15 @@ public class Solver<D extends DataStructureFactory> implements ISolver,
 	}
 
 	public boolean model(int var) {
-		if (var <= 0 || var > nVars()) {
+		if (var <= 0 || var > realNumberOfVariables()) {
 			throw new IllegalArgumentException(
 					"Use a valid Dimacs var id as argument!"); //$NON-NLS-1$
 		}
-		if (fullmodel == null) {
+		if (userbooleanmodel == null) {
 			throw new UnsupportedOperationException(
 					"Call the solve method first!!!"); //$NON-NLS-1$
 		}
-		return fullmodel[var - 1];
+		return userbooleanmodel[var - 1];
 	}
 
 	public void clearLearntClauses() {
@@ -1552,16 +1610,28 @@ public class Solver<D extends DataStructureFactory> implements ISolver,
 		learnedLiterals.ensure(howmany);
 		decisions.clear();
 		implied.clear();
-		timebegin = System.currentTimeMillis();
 		slistener.start();
 		model = null; // forget about previous model
-		fullmodel = null;
+		userbooleanmodel = null;
 		unsatExplanationInTermsOfAssumptions = null;
 		order.init();
 		learnedConstraintsDeletionStrategy.init();
-
 		int learnedLiteralsLimit = trail.size();
 
+		// Fix for Bug SAT37
+		qhead = 0;
+		// Apply undos on unit literals because they are getting propagated
+		// again now that qhead is 0.
+		for (int i = learnedLiteralsLimit - 1; i >= 0; i--) {
+			int p = trail.get(i);
+			IVec<Undoable> undos = voc.undos(p);
+			assert undos != null;
+			for (int size = undos.size(); size > 0; size--) {
+				undos.last().undo(p);
+				undos.pop();
+			}
+		}
+
 		// push previously learned literals
 		for (IteratorInt iterator = learnedLiterals.iterator(); iterator
 				.hasNext();) {
@@ -1583,7 +1653,8 @@ public class Solver<D extends DataStructureFactory> implements ISolver,
 		for (IteratorInt iterator = assumps.iterator(); iterator.hasNext();) {
 			int assump = iterator.next();
 			int p = voc.getFromPool(assump);
-			if (!assume(p) || ((confl = propagate()) != null)) {
+			if ((!voc.isSatisfied(p) && !assume(p))
+					|| ((confl = propagate()) != null)) {
 				if (confl == null) {
 					slistener.conflictFound(p);
 					unsatExplanationInTermsOfAssumptions = analyzeFinalConflictInTermsOfAssumptions(
@@ -1641,8 +1712,10 @@ public class Solver<D extends DataStructureFactory> implements ISolver,
 						learnedConstraintsDeletionStrategy.getTimer());
 			}
 		}
-		if (!global || firstTimeGlobal)
+		if (!global || firstTimeGlobal) {
 			restarter.init(params);
+			timebegin = System.currentTimeMillis();
+		}
 		needToReduceDB = false;
 		// Solve
 		while ((status == Lbool.UNDEFINED) && undertimeout) {
@@ -1671,9 +1744,14 @@ public class Solver<D extends DataStructureFactory> implements ISolver,
 	public void printInfos(PrintWriter out, String prefix) {
 		out.print(prefix);
 		out.println("constraints type ");
+		long total = 0;
 		for (Map.Entry<String, Counter> entry : constrTypes.entrySet()) {
 			out.println(prefix + entry.getKey() + " => " + entry.getValue());
+			total += entry.getValue().getValue();
 		}
+		out.print(prefix);
+		out.print(total);
+		out.println(" constraints processed.");
 	}
 
 	/**
@@ -1738,7 +1816,10 @@ public class Solver<D extends DataStructureFactory> implements ISolver,
 	}
 
 	public int nVars() {
-		return voc.nVars();
+		if (declaredMaxVarId == 0) {
+			return voc.nVars();
+		}
+		return declaredMaxVarId;
 	}
 
 	/**
@@ -1747,7 +1828,14 @@ public class Solver<D extends DataStructureFactory> implements ISolver,
 	 * @return a reference to the constraint for external use.
 	 */
 	protected IConstr addConstr(Constr constr) {
-		if (constr != null) {
+		if (constr == null) {
+			Counter count = constrTypes.get("ignored satisfied constraints");
+			if (count == null) {
+				constrTypes.put("ignored satisfied constraints", new Counter());
+			} else {
+				count.inc();
+			}
+		} else {
 			constrs.push(constr);
 			String type = constr.getClass().getName();
 			Counter count = constrTypes.get(type);
@@ -1912,9 +2000,9 @@ public class Solver<D extends DataStructureFactory> implements ISolver,
 	 * @since 2.1
 	 */
 	public void unset(int p) {
-		// the literal might already been
+		// the literal might already have been
 		// removed from the trail.
-		if (trail.isEmpty()) {
+		if (voc.isUnassigned(p) || trail.isEmpty()) {
 			return;
 		}
 		int current = trail.last();
@@ -1952,6 +2040,33 @@ public class Solver<D extends DataStructureFactory> implements ISolver,
 		return copy;
 	}
 
+	/**
+	 * @since 2.3.1
+	 */
+	public int[] modelWithInternalVariables() {
+		if (model == null) {
+			throw new UnsupportedOperationException(
+					"Call the solve method first!!!"); //$NON-NLS-1$
+		}
+		int[] nmodel;
+		if (nVars() == realNumberOfVariables()) {
+			nmodel = new int[model.length];
+			System.arraycopy(model, 0, nmodel, 0, nmodel.length);
+		} else {
+			nmodel = new int[fullmodel.length];
+			System.arraycopy(fullmodel, 0, nmodel, 0, nmodel.length);
+		}
+
+		return nmodel;
+	}
+
+	/**
+	 * @since 2.3.1
+	 */
+	public int realNumberOfVariables() {
+		return voc.nVars();
+	}
+
 }
 
 class ActivityComparator implements Comparator<Constr>, Serializable {
