@@ -194,4 +194,15 @@ public interface IVecInt extends Serializable {
 	 * @since 2.1
 	 */
 	int[] toArray();
+
+	/**
+	 * Compute all subsets of cardinal k of the vector.
+	 * 
+	 * @param k
+	 *            a cardinal (k<= vec.size())
+	 * @return an array of IVectInt representing each a k-subset of this vector.
+	 * @author sroussel
+	 * @since 2.3.1
+	 */
+	public IVecInt[] subset(int k);
 }
