@@ -126,6 +126,18 @@ public class DimacsOutputSolver extends AbstractOutputSolver {
 		return addClause(literals);
 	}
 
+	public IConstr addExactly(IVecInt literals, int n)
+			throws ContradictionException {
+		if (n > 1) {
+			throw new UnsupportedOperationException(
+					"Not a clausal problem! degree " + n);
+		}
+		assert n == 1;
+		addAtMost(literals, n);
+		addAtLeast(literals, n);
+		return null;
+	}
+
 	public void reset() {
 		fixedNbClauses = false;
 		firstConstr = true;
@@ -148,6 +160,30 @@ public class DimacsOutputSolver extends AbstractOutputSolver {
 	 * @since 2.1
 	 */
 	public int nextFreeVarId(boolean reserve) {
+		if (reserve) {
+			return ++nbvars;
+		}
+		return nbvars + 1;
+	}
+
+	/**
+	 * @since 2.3.1
+	 */
+	public int[] modelWithInternalVariables() {
+		throw new UnsupportedOperationException();
+	}
+
+	/**
+	 * @since 2.3.1
+	 */
+	public int realNumberOfVariables() {
+		return nbvars;
+	}
+
+	/**
+	 * @since 2.3.1
+	 */
+	public void registerLiteral(int p) {
 		throw new UnsupportedOperationException();
 	}
 }
