@@ -27,18 +27,10 @@
  *******************************************************************************/
 package org.sat4j.tools;
 
-import java.io.PrintStream;
-import java.io.PrintWriter;
-import java.util.Map;
-
 import org.sat4j.specs.ContradictionException;
 import org.sat4j.specs.IConstr;
-import org.sat4j.specs.ISolver;
-import org.sat4j.specs.IVec;
 import org.sat4j.specs.IVecInt;
 import org.sat4j.specs.IteratorInt;
-import org.sat4j.specs.SearchListener;
-import org.sat4j.specs.TimeoutException;
 
 /**
  * Solver used to write down a CNF into a String.
@@ -49,7 +41,7 @@ import org.sat4j.specs.TimeoutException;
  * @author leberre
  * 
  */
-public class DimacsStringSolver implements ISolver {
+public class DimacsStringSolver extends AbstractOutputSolver {
 
 	/**
      * 
@@ -58,14 +50,6 @@ public class DimacsStringSolver implements ISolver {
 
 	private StringBuffer out;
 
-	private int nbvars;
-
-	private int nbclauses;
-
-	private boolean fixedNbClauses = false;
-
-	private boolean firstConstr = true;
-
 	private int firstCharPos;
 
 	private final int initBuilderSize;
@@ -126,15 +110,6 @@ public class DimacsStringSolver implements ISolver {
 		return null;
 	}
 
-	public boolean removeConstr(IConstr c) {
-		throw new UnsupportedOperationException();
-	}
-
-	public void addAllClauses(IVec<IVecInt> clauses)
-			throws ContradictionException {
-		throw new UnsupportedOperationException();
-	}
-
 	public IConstr addAtMost(IVecInt literals, int degree)
 			throws ContradictionException {
 		if (degree > 1) {
@@ -164,6 +139,18 @@ public class DimacsStringSolver implements ISolver {
 		return null;
 	}
 
+	public IConstr addExactly(IVecInt literals, int n)
+			throws ContradictionException {
+		if (n > 1) {
+			throw new UnsupportedOperationException(
+					"Not a clausal problem! degree " + n);
+		}
+		assert n == 1;
+		addAtMost(literals, n);
+		addAtLeast(literals, n);
+		return null;
+	}
+
 	public IConstr addAtLeast(IVecInt literals, int degree)
 			throws ContradictionException {
 		if (degree > 1) {
@@ -174,26 +161,6 @@ public class DimacsStringSolver implements ISolver {
 		return addClause(literals);
 	}
 
-	public void setTimeout(int t) {
-		// TODO Auto-generated method stub
-
-	}
-
-	public void setTimeoutMs(long t) {
-		// TODO Auto-generated method stub
-	}
-
-	public int getTimeout() {
-		return 0;
-	}
-
-	/**
-	 * @since 2.1
-	 */
-	public long getTimeoutMs() {
-		return 0L;
-	}
-
 	public void reset() {
 		fixedNbClauses = false;
 		firstConstr = true;
@@ -201,53 +168,10 @@ public class DimacsStringSolver implements ISolver {
 		maxvarid = 0;
 	}
 
-	public void printStat(PrintStream output, String prefix) {
-		// TODO Auto-generated method stub
-	}
-
-	public void printStat(PrintWriter output, String prefix) {
-		// TODO Auto-generated method stub
-
-	}
-
-	public Map<String, Number> getStat() {
-		// TODO Auto-generated method stub
-		return null;
-	}
-
 	public String toString(String prefix) {
 		return "Dimacs output solver";
 	}
 
-	public void clearLearntClauses() {
-		// TODO Auto-generated method stub
-
-	}
-
-	public int[] model() {
-		throw new UnsupportedOperationException();
-	}
-
-	public boolean model(int var) {
-		throw new UnsupportedOperationException();
-	}
-
-	public boolean isSatisfiable() throws TimeoutException {
-		throw new TimeoutException("There is no real solver behind!");
-	}
-
-	public boolean isSatisfiable(IVecInt assumps) throws TimeoutException {
-		throw new TimeoutException("There is no real solver behind!");
-	}
-
-	public int[] findModel() throws TimeoutException {
-		throw new UnsupportedOperationException();
-	}
-
-	public int[] findModel(IVecInt assumps) throws TimeoutException {
-		throw new UnsupportedOperationException();
-	}
-
 	public int nConstraints() {
 		return nbclauses;
 	}
@@ -258,116 +182,32 @@ public class DimacsStringSolver implements ISolver {
 
 	@Override
 	public String toString() {
-		// String numClauses = Integer.toString(nbclauses);
-		// int numClausesLength = numClauses.length();
-		// for (int i = 0; i < numClausesLength; ++i) {
-		// out.setCharAt(firstCharPos + i, numClauses.charAt(i));
-		// }
 		out.insert(firstCharPos, "p cnf " + maxvarid + " " + nbclauses);
 		return out.toString();
 	}
 
-	public void expireTimeout() {
-		// TODO Auto-generated method stub
-
-	}
-
-	public boolean isSatisfiable(IVecInt assumps, boolean global)
-			throws TimeoutException {
-		throw new TimeoutException("There is no real solver behind!");
-	}
-
-	public boolean isSatisfiable(boolean global) throws TimeoutException {
-		throw new TimeoutException("There is no real solver behind!");
-	}
-
-	public void printInfos(PrintWriter output, String prefix) {
-	}
-
-	public void setTimeoutOnConflicts(int count) {
-
-	}
-
-	public boolean isDBSimplificationAllowed() {
-		return false;
-	}
-
-	public void setDBSimplificationAllowed(boolean status) {
-
-	}
-
-	/**
-	 * @since 2.1
-	 */
-	public void setSearchListener(SearchListener sl) {
-	}
-
 	/**
 	 * @since 2.1
 	 */
 	public int nextFreeVarId(boolean reserve) {
 		if (reserve) {
-			maxvarid++;
-			return maxvarid;
+			return ++maxvarid;
 		}
+		return maxvarid + 1;
+	}
+
+	/**
+	 * @since 2.3.1
+	 */
+	public int[] modelWithInternalVariables() {
+		throw new UnsupportedOperationException();
+	}
+
+	public int realNumberOfVariables() {
 		return maxvarid;
 	}
 
-	/**
-	 * @since 2.1
-	 */
-	public boolean removeSubsumedConstr(IConstr c) {
-		return false;
-	}
-
-	/**
-	 * @since 2.1
-	 */
-	public IConstr addBlockingClause(IVecInt literals)
-			throws ContradictionException {
-		throw new UnsupportedOperationException();
-	}
-
-	/**
-	 * @since 2.2
-	 */
-	public SearchListener getSearchListener() {
-		throw new UnsupportedOperationException();
-	}
-
-	/**
-	 * @since 2.2
-	 */
-	public boolean isVerbose() {
-		return true;
-	}
-
-	/**
-	 * @since 2.2
-	 */
-	public void setVerbose(boolean value) {
-		// do nothing
-	}
-
-	/**
-	 * @since 2.2
-	 */
-	public void setLogPrefix(String prefix) {
-		// do nothing
-
-	}
-
-	/**
-	 * @since 2.2
-	 */
-	public String getLogPrefix() {
-		return "";
-	}
-
-	/**
-	 * @since 2.2
-	 */
-	public IVecInt unsatExplanation() {
+	public void registerLiteral(int p) {
 		throw new UnsupportedOperationException();
 	}
 }
