@@ -40,7 +40,7 @@ import org.sat4j.specs.SearchListener;
 import org.sat4j.specs.TimeoutException;
 
 /**
- * The aim of that class is to allow adding dynamic responsabilities to SAT
+ * The aim of that class is to allow adding dynamic responsibilities to SAT
  * solvers using the Decorator design pattern. The class is abstract because it
  * does not makes sense to use it "as is".
  * 
@@ -167,7 +167,7 @@ public abstract class SolverDecorator<T extends ISolver> implements ISolver {
 
 	@Override
 	public String toString() {
-		return solver.toString();
+		return toString("");
 	}
 
 	/*
@@ -435,4 +435,33 @@ public abstract class SolverDecorator<T extends ISolver> implements ISolver {
 		return solver.primeImplicant();
 	}
 
+	/**
+	 * @since 2.3.1
+	 */
+	public IConstr addExactly(IVecInt literals, int n)
+			throws ContradictionException {
+		return solver.addExactly(literals, n);
+	}
+
+	/**
+	 * @since 2.3.1
+	 */
+	public int[] modelWithInternalVariables() {
+		return solver.modelWithInternalVariables();
+	}
+
+	/**
+	 * @since 2.3.1
+	 */
+	public int realNumberOfVariables() {
+		return solver.realNumberOfVariables();
+	}
+
+	/**
+	 * @since 2.3.1
+	 */
+	public void registerLiteral(int p) {
+		solver.registerLiteral(p);
+	}
+
 }
