@@ -1,30 +1,30 @@
 /*******************************************************************************
-* SAT4J: a SATisfiability library for Java Copyright (C) 2004-2008 Daniel Le Berre
-*
-* All rights reserved. This program and the accompanying materials
-* are made available under the terms of the Eclipse Public License v1.0
-* which accompanies this distribution, and is available at
-* http://www.eclipse.org/legal/epl-v10.html
-*
-* Alternatively, the contents of this file may be used under the terms of
-* either the GNU Lesser General Public License Version 2.1 or later (the
-* "LGPL"), in which case the provisions of the LGPL are applicable instead
-* of those above. If you wish to allow use of your version of this file only
-* under the terms of the LGPL, and not to allow others to use your version of
-* this file under the terms of the EPL, indicate your decision by deleting
-* the provisions above and replace them with the notice and other provisions
-* required by the LGPL. If you do not delete the provisions above, a recipient
-* may use your version of this file under the terms of the EPL or the LGPL.
-* 
-* Based on the original MiniSat specification from:
-* 
-* An extensible SAT solver. Niklas Een and Niklas Sorensson. Proceedings of the
-* Sixth International Conference on Theory and Applications of Satisfiability
-* Testing, LNCS 2919, pp 502-518, 2003.
-*
-* See www.minisat.se for the original solver in C++.
-* 
-*******************************************************************************/
+ * SAT4J: a SATisfiability library for Java Copyright (C) 2004-2008 Daniel Le Berre
+ *
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Alternatively, the contents of this file may be used under the terms of
+ * either the GNU Lesser General Public License Version 2.1 or later (the
+ * "LGPL"), in which case the provisions of the LGPL are applicable instead
+ * of those above. If you wish to allow use of your version of this file only
+ * under the terms of the LGPL, and not to allow others to use your version of
+ * this file under the terms of the EPL, indicate your decision by deleting
+ * the provisions above and replace them with the notice and other provisions
+ * required by the LGPL. If you do not delete the provisions above, a recipient
+ * may use your version of this file under the terms of the EPL or the LGPL.
+ * 
+ * Based on the original MiniSat specification from:
+ * 
+ * An extensible SAT solver. Niklas Een and Niklas Sorensson. Proceedings of the
+ * Sixth International Conference on Theory and Applications of Satisfiability
+ * Testing, LNCS 2919, pp 502-518, 2003.
+ *
+ * See www.minisat.se for the original solver in C++.
+ * 
+ *******************************************************************************/
 package org.sat4j;
 
 import static org.junit.Assert.assertEquals;
@@ -32,13 +32,13 @@ import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
 
 import org.junit.Test;
+import org.sat4j.core.ConstrGroup;
 import org.sat4j.core.VecInt;
 import org.sat4j.minisat.SolverFactory;
 import org.sat4j.specs.ContradictionException;
 import org.sat4j.specs.ISolver;
 import org.sat4j.specs.IVecInt;
 import org.sat4j.specs.TimeoutException;
-import org.sat4j.tools.ConstrGroup;
 
 public class TestConstrGroup {
 
@@ -60,13 +60,14 @@ public class TestConstrGroup {
 		assertEquals(1, solver.nConstraints());
 	}
 
-	@Test(expected = java.lang.IllegalArgumentException.class)
-	public void cannotPutAUnitClauseInAGroup() throws ContradictionException {
+	@Test
+	public void canPutAUnitClauseInAGroup() throws ContradictionException {
 		ISolver solver = SolverFactory.newDefault();
 		ConstrGroup g1 = new ConstrGroup();
 
 		IVecInt clause = new VecInt(new int[] { 1 });
 		g1.add(solver.addClause(clause));
+		assertEquals(1, solver.nConstraints());
 	}
 
 	@Test
@@ -90,9 +91,10 @@ public class TestConstrGroup {
 		g1.removeFrom(solver);
 		assertEquals(1, solver.nConstraints());
 	}
-	
+
 	@Test
-	public void checkItWorksAfterRunningTheSolver() throws ContradictionException, TimeoutException {
+	public void checkItWorksAfterRunningTheSolver()
+			throws ContradictionException, TimeoutException {
 		ISolver solver = SolverFactory.newDefault();
 		ConstrGroup g1 = new ConstrGroup();
 
@@ -114,9 +116,10 @@ public class TestConstrGroup {
 		g1.removeFrom(solver);
 		assertEquals(1, solver.nConstraints());
 	}
-	
-	@Test(expected = java.lang.IllegalArgumentException.class)
-	public void checkGroupDoesNotWorkWhenClausesAreReducedByUnitPropgation() throws ContradictionException {
+
+	@Test
+	public void checkGroupDoesWorkWhenClausesAreReducedByUnitPropgation()
+			throws ContradictionException {
 		ISolver solver = SolverFactory.newDefault();
 		ConstrGroup g1 = new ConstrGroup();
 
@@ -127,10 +130,12 @@ public class TestConstrGroup {
 		clause.clear();
 		clause.push(-1).push(-2);
 		g1.add(solver.addClause(clause));
+		assertEquals(1, g1.size());
 	}
-	
+
 	@Test
-	public void checkTheExpectedWayToDealWithUnitClausesToRemove() throws ContradictionException, TimeoutException {
+	public void checkTheExpectedWayToDealWithUnitClausesToRemove()
+			throws ContradictionException, TimeoutException {
 		ISolver solver = SolverFactory.newDefault();
 		ConstrGroup g1 = new ConstrGroup();
 
@@ -139,17 +144,17 @@ public class TestConstrGroup {
 
 		// starting group
 		clause.clear();
-		clause.push(2).push(-3);		
+		clause.push(2).push(-3);
 		g1.add(solver.addClause(clause));
-	
+
 		clause.clear();
-		clause.push(-2).push(4);		
+		clause.push(-2).push(4);
 		g1.add(solver.addClause(clause));
-		
-		IVecInt unitClauses = new VecInt(new int[] {3,-4});
-		
+
+		IVecInt unitClauses = new VecInt(new int[] { 3, -4 });
+
 		assertFalse(solver.isSatisfiable(unitClauses));
-		
+
 		g1.removeFrom(solver);
 		assertTrue(solver.isSatisfiable(unitClauses));
 	}
