@@ -5,7 +5,7 @@ import org.sat4j.specs.ISolver;
 import org.sat4j.tools.xplain.DeletionStrategy;
 import org.sat4j.tools.xplain.Xplain;
 
-public class TestDeletionXplain extends AbstractXplainTest {
+public class TestDeletionXplain extends AbstractXplainTest<ISolver> {
 
 	@Override
 	protected Xplain<ISolver> getXplain() {
