@@ -5,7 +5,7 @@ import org.sat4j.specs.ISolver;
 import org.sat4j.tools.xplain.InsertionStrategy;
 import org.sat4j.tools.xplain.Xplain;
 
-public class TestInsertionXplain extends AbstractXplainTest {
+public class TestInsertionXplain extends AbstractXplainTest<ISolver> {
 
 	@Override
 	protected Xplain<ISolver> getXplain() {
