@@ -79,6 +79,10 @@ public class OPBStringSolver extends DimacsStringSolver implements IPBSolver {
 		public int get(int i) {
 			throw new UnsupportedOperationException(FAKE_I_CONSTR_MSG);
 		}
+
+		public boolean canBePropagatedMultipleTimes() {
+			throw new UnsupportedOperationException(FAKE_I_CONSTR_MSG);
+		}
 	};
 
 	/**
@@ -111,37 +115,15 @@ public class OPBStringSolver extends DimacsStringSolver implements IPBSolver {
 	@Override
 	public boolean isSatisfiable(IVecInt assumps, boolean global)
 			throws TimeoutException {
-		// TODO Auto-generated method stub
 		return super.isSatisfiable(assumps, global);
 	}
 
 	public IConstr addPseudoBoolean(IVecInt lits, IVec<BigInteger> coeffs,
 			boolean moreThan, BigInteger d) throws ContradictionException {
-		StringBuffer out = getOut();
-		assert lits.size() == coeffs.size();
-		nbOfConstraints++;
 		if (moreThan) {
-			for (int i = 0; i < lits.size(); i++) {
-				out.append(coeffs.get(i));
-				out.append(" x");
-				out.append(lits.get(i));
-				out.append(" ");
-			}
-			out.append(">= ");
-			out.append(d);
-			out.append(" ;\n");
-		} else {
-			for (int i = 0; i < lits.size(); i++) {
-				out.append(coeffs.get(i).negate());
-				out.append(" x");
-				out.append(lits.get(i));
-				out.append(" ");
-			}
-			out.append(">= ");
-			out.append(d.negate());
-			out.append(" ;\n");
+			return addAtLeast(lits, coeffs, d);
 		}
-		return FAKE_CONSTR;
+		return addAtMost(lits, coeffs, d);
 	}
 
 	public void setObjectiveFunction(ObjectiveFunction obj) {
@@ -153,9 +135,19 @@ public class OPBStringSolver extends DimacsStringSolver implements IPBSolver {
 			throws ContradictionException {
 		StringBuffer out = getOut();
 		nbOfConstraints++;
-		for (IteratorInt iterator = literals.iterator(); iterator.hasNext();)
-			out.append("+1 x" + iterator.next() + " ");
-		out.append(">= " + degree + " ;\n");
+		int negationweight = 0;
+		int p;
+		for (IteratorInt iterator = literals.iterator(); iterator.hasNext();) {
+			p = iterator.next();
+			assert p != 0;
+			if (p > 0) {
+				out.append("+1 x" + p + " ");
+			} else {
+				out.append("-1 x" + (-p) + " ");
+				negationweight++;
+			}
+		}
+		out.append(">= " + (degree - negationweight) + " ;\n");
 		return FAKE_CONSTR;
 	}
 
@@ -164,9 +156,19 @@ public class OPBStringSolver extends DimacsStringSolver implements IPBSolver {
 			throws ContradictionException {
 		StringBuffer out = getOut();
 		nbOfConstraints++;
-		for (IteratorInt iterator = literals.iterator(); iterator.hasNext();)
-			out.append("-1 x" + iterator.next() + " ");
-		out.append(">= " + (-degree) + " ;\n");
+		int negationweight = 0;
+		int p;
+		for (IteratorInt iterator = literals.iterator(); iterator.hasNext();) {
+			p = iterator.next();
+			assert p != 0;
+			if (p > 0) {
+				out.append("-1 x" + p + " ");
+			} else {
+				out.append("+1 x" + (-p) + " ");
+				negationweight++;
+			}
+		}
+		out.append(">= " + (-degree + negationweight) + " ;\n");
 		return FAKE_CONSTR;
 	}
 
@@ -218,11 +220,11 @@ public class OPBStringSolver extends DimacsStringSolver implements IPBSolver {
 			tmp.append(nVars());
 			tmp.append(" #constraint= ");
 			tmp.append(nbOfConstraints);
-			tmp.append(" \n");
 			if (obj != null) {
+				tmp.append("\n");
 				tmp.append("min: ");
 				tmp.append(obj);
-				tmp.append(" ;\n");
+				tmp.append(";");
 			}
 			out.insert(indxConstrObj, tmp.toString());
 			inserted = true;
@@ -258,4 +260,107 @@ public class OPBStringSolver extends DimacsStringSolver implements IPBSolver {
 		return nbOfConstraints;
 	}
 
+	public IConstr addAtMost(IVecInt literals, IVecInt coeffs, int degree)
+			throws ContradictionException {
+		StringBuffer out = getOut();
+		assert literals.size() == coeffs.size();
+		nbOfConstraints++;
+		for (int i = 0; i < literals.size(); i++) {
+			out.append(-coeffs.get(i));
+			out.append(" x");
+			out.append(literals.get(i));
+			out.append(" ");
+		}
+		out.append(">= ");
+		out.append(-degree);
+		out.append(" ;\n");
+		return FAKE_CONSTR;
+	}
+
+	public IConstr addAtMost(IVecInt literals, IVec<BigInteger> coeffs,
+			BigInteger degree) throws ContradictionException {
+		StringBuffer out = getOut();
+		assert literals.size() == coeffs.size();
+		nbOfConstraints++;
+		for (int i = 0; i < literals.size(); i++) {
+			out.append(coeffs.get(i).negate());
+			out.append(" x");
+			out.append(literals.get(i));
+			out.append(" ");
+		}
+		out.append(">= ");
+		out.append(degree.negate());
+		out.append(" ;\n");
+		return FAKE_CONSTR;
+	}
+
+	public IConstr addAtLeast(IVecInt literals, IVecInt coeffs, int degree)
+			throws ContradictionException {
+		StringBuffer out = getOut();
+		assert literals.size() == coeffs.size();
+		nbOfConstraints++;
+		for (int i = 0; i < literals.size(); i++) {
+			out.append(coeffs.get(i));
+			out.append(" x");
+			out.append(literals.get(i));
+			out.append(" ");
+		}
+		out.append(">= ");
+		out.append(degree);
+		out.append(" ;\n");
+		return FAKE_CONSTR;
+	}
+
+	public IConstr addAtLeast(IVecInt literals, IVec<BigInteger> coeffs,
+			BigInteger degree) throws ContradictionException {
+		StringBuffer out = getOut();
+		assert literals.size() == coeffs.size();
+		nbOfConstraints++;
+		for (int i = 0; i < literals.size(); i++) {
+			out.append(coeffs.get(i));
+			out.append(" x");
+			out.append(literals.get(i));
+			out.append(" ");
+		}
+		out.append(">= ");
+		out.append(degree);
+		out.append(" ;\n");
+		return FAKE_CONSTR;
+
+	}
+
+	public IConstr addExactly(IVecInt literals, IVecInt coeffs, int weight)
+			throws ContradictionException {
+		StringBuffer out = getOut();
+		assert literals.size() == coeffs.size();
+		nbOfConstraints++;
+		for (int i = 0; i < literals.size(); i++) {
+			out.append(coeffs.get(i));
+			out.append(" x");
+			out.append(literals.get(i));
+			out.append(" ");
+		}
+		out.append("= ");
+		out.append(weight);
+		out.append(" ;\n");
+		return FAKE_CONSTR;
+	}
+
+	public IConstr addExactly(IVecInt literals, IVec<BigInteger> coeffs,
+			BigInteger weight) throws ContradictionException {
+		StringBuffer out = getOut();
+		assert literals.size() == coeffs.size();
+		nbOfConstraints++;
+		for (int i = 0; i < literals.size(); i++) {
+			out.append(coeffs.get(i));
+			out.append(" x");
+			out.append(literals.get(i));
+			out.append(" ");
+		}
+		out.append("= ");
+		out.append(weight);
+		out.append(" ;\n");
+		return FAKE_CONSTR;
+	}
+
 }
