@@ -66,4 +66,34 @@ public class PBSolverDecorator extends SolverDecorator<IPBSolver> implements
 		return decorated().getObjectiveFunction();
 	}
 
+	public IConstr addAtMost(IVecInt literals, IVecInt coeffs, int degree)
+			throws ContradictionException {
+		return decorated().addAtMost(literals, coeffs, degree);
+	}
+
+	public IConstr addAtMost(IVecInt literals, IVec<BigInteger> coeffs,
+			BigInteger degree) throws ContradictionException {
+		return decorated().addAtMost(literals, coeffs, degree);
+	}
+
+	public IConstr addAtLeast(IVecInt literals, IVecInt coeffs, int degree)
+			throws ContradictionException {
+		return decorated().addAtLeast(literals, coeffs, degree);
+	}
+
+	public IConstr addAtLeast(IVecInt literals, IVec<BigInteger> coeffs,
+			BigInteger degree) throws ContradictionException {
+		return decorated().addAtLeast(literals, coeffs, degree);
+	}
+
+	public IConstr addExactly(IVecInt literals, IVecInt coeffs, int weight)
+			throws ContradictionException {
+		return decorated().addExactly(literals, coeffs, weight);
+	}
+
+	public IConstr addExactly(IVecInt literals, IVec<BigInteger> coeffs,
+			BigInteger weight) throws ContradictionException {
+		return decorated().addExactly(literals, coeffs, weight);
+	}
+
 }
