@@ -30,6 +30,7 @@ package org.sat4j.pb;
 import org.sat4j.core.ASolverFactory;
 import org.sat4j.minisat.core.IOrder;
 import org.sat4j.minisat.core.IPhaseSelectionStrategy;
+import org.sat4j.minisat.core.Solver;
 import org.sat4j.minisat.learning.ClauseOnlyLearning;
 import org.sat4j.minisat.learning.MiniSATLearning;
 import org.sat4j.minisat.learning.NoLearningButHeuristics;
@@ -39,12 +40,15 @@ import org.sat4j.minisat.orders.UserFixedPhaseSelectionStrategy;
 import org.sat4j.minisat.orders.VarOrderHeap;
 import org.sat4j.minisat.restarts.ArminRestarts;
 import org.sat4j.minisat.restarts.MiniSATRestarts;
-import org.sat4j.minisat.uip.FirstUIP;
 import org.sat4j.pb.constraints.AbstractPBDataStructureFactory;
 import org.sat4j.pb.constraints.CompetMinHTmixedClauseCardConstrDataStructureFactory;
+import org.sat4j.pb.constraints.CompetResolutionMinPBLongMixedWLClauseCardConstrDataStructure;
+import org.sat4j.pb.constraints.CompetResolutionPBLongMixedHTClauseCardConstrDataStructure;
+import org.sat4j.pb.constraints.CompetResolutionPBLongMixedWLClauseCardConstrDataStructure;
 import org.sat4j.pb.constraints.CompetResolutionPBMixedHTClauseCardConstrDataStructure;
 import org.sat4j.pb.constraints.CompetResolutionPBMixedWLClauseCardConstrDataStructure;
-import org.sat4j.pb.constraints.PBMaxCBClauseCardConstrDataStructure;
+import org.sat4j.pb.constraints.PBLongMaxClauseCardConstrDataStructure;
+import org.sat4j.pb.constraints.PBLongMinClauseCardConstrDataStructure;
 import org.sat4j.pb.constraints.PBMaxClauseAtLeastConstrDataStructure;
 import org.sat4j.pb.constraints.PBMaxClauseCardConstrDataStructure;
 import org.sat4j.pb.constraints.PBMaxDataStructure;
@@ -61,6 +65,7 @@ import org.sat4j.pb.core.PBSolverResCP;
 import org.sat4j.pb.core.PBSolverResolution;
 import org.sat4j.pb.core.PBSolverWithImpliedClause;
 import org.sat4j.pb.orders.VarOrderHeapObjective;
+import org.sat4j.pb.tools.ManyCorePB;
 import org.sat4j.specs.ISolver;
 import org.sat4j.tools.DimacsOutputSolver;
 
@@ -155,6 +160,21 @@ public class SolverFactory extends ASolverFactory<IPBSolver> {
 				new VarOrderHeapObjective());
 	}
 
+	public static PBSolverCP newCompetPBCPMixedConstraintsMinObjective() {
+		return newPBCP(new PBMinClauseCardConstrDataStructure(),
+				new VarOrderHeapObjective());
+	}
+
+	public static PBSolverCP newCompetPBCPMixedConstraintsLongMaxObjective() {
+		return newPBCP(new PBLongMaxClauseCardConstrDataStructure(),
+				new VarOrderHeapObjective());
+	}
+
+	public static PBSolverCP newCompetPBCPMixedConstraintsLongMinObjective() {
+		return newPBCP(new PBLongMinClauseCardConstrDataStructure(),
+				new VarOrderHeapObjective());
+	}
+
 	/**
 	 * @return MiniLearning with Counter-based pseudo boolean constraints and
 	 *         constraint learning. Clauses and cardinalities with watched
@@ -165,7 +185,7 @@ public class SolverFactory extends ASolverFactory<IPBSolver> {
 	 */
 	public static PBSolverCP newPBCPMixedConstraintsObjectiveLearnJustClauses() {
 		ClauseOnlyLearning<PBDataStructureFactory> learning = new ClauseOnlyLearning<PBDataStructureFactory>();
-		PBSolverCP solver = new PBSolverCP(new FirstUIP(), learning,
+		PBSolverCP solver = new PBSolverCP(learning,
 				new PBMaxClauseCardConstrDataStructure(),
 				new VarOrderHeapObjective());
 		learning.setSolver(solver);
@@ -174,7 +194,7 @@ public class SolverFactory extends ASolverFactory<IPBSolver> {
 
 	public static PBSolverCP newCompetPBCPMixedConstraintsObjectiveLearnJustClauses() {
 		ClauseOnlyLearning<PBDataStructureFactory> learning = new ClauseOnlyLearning<PBDataStructureFactory>();
-		PBSolverCP solver = new PBSolverCP(new FirstUIP(), learning,
+		PBSolverCP solver = new PBSolverCP(learning,
 				new PBMaxClauseCardConstrDataStructure(),
 				new VarOrderHeapObjective());
 		learning.setSolver(solver);
@@ -183,7 +203,7 @@ public class SolverFactory extends ASolverFactory<IPBSolver> {
 
 	private static PBSolverCP newPBKiller(IPhaseSelectionStrategy phase) {
 		ClauseOnlyLearning<PBDataStructureFactory> learning = new ClauseOnlyLearning<PBDataStructureFactory>();
-		PBSolverCP solver = new PBSolverCP(new FirstUIP(), learning,
+		PBSolverCP solver = new PBSolverCP(learning,
 				new PBMaxClauseCardConstrDataStructure(),
 				new VarOrderHeapObjective(phase));
 		learning.setSolver(solver);
@@ -204,7 +224,7 @@ public class SolverFactory extends ASolverFactory<IPBSolver> {
 
 	private static PBSolverCP newCompetPBKiller(IPhaseSelectionStrategy phase) {
 		ClauseOnlyLearning<PBDataStructureFactory> learning = new ClauseOnlyLearning<PBDataStructureFactory>();
-		PBSolverCP solver = new PBSolverCP(new FirstUIP(), learning,
+		PBSolverCP solver = new PBSolverCP(learning,
 				new PBMaxClauseCardConstrDataStructure(),
 				new VarOrderHeapObjective(phase));
 		learning.setSolver(solver);
@@ -234,7 +254,7 @@ public class SolverFactory extends ASolverFactory<IPBSolver> {
 		// LimitedLearning learning = new LimitedLearning(10);
 		MiniSATLearning<PBDataStructureFactory> learning = new MiniSATLearning<PBDataStructureFactory>();
 		// LearningStrategy learning = new NoLearningButHeuristics();
-		PBSolverCP solver = new PBSolverClause(new FirstUIP(), learning,
+		PBSolverCP solver = new PBSolverClause(learning,
 				new PBMaxClauseCardConstrDataStructure(),
 				new VarOrderHeapObjective());
 		learning.setDataStructureFactory(solver.getDSFactory());
@@ -252,7 +272,7 @@ public class SolverFactory extends ASolverFactory<IPBSolver> {
 	public static PBSolverCP newPBCPMixedConstraintsObjectiveNoLearning() {
 		NoLearningButHeuristics<PBDataStructureFactory> learning = new NoLearningButHeuristics<PBDataStructureFactory>();
 		// SearchParams params = new SearchParams(1.1,100);
-		PBSolverCP solver = new PBSolverCP(new FirstUIP(), learning,
+		PBSolverCP solver = new PBSolverCP(learning,
 				new PBMaxClauseCardConstrDataStructure(),
 				new VarOrderHeapObjective());
 		learning.setSolver(solver);
@@ -262,30 +282,43 @@ public class SolverFactory extends ASolverFactory<IPBSolver> {
 
 	public static PBSolverResolution newPBResMixedConstraintsObjective() {
 		MiniSATLearning<PBDataStructureFactory> learning = new MiniSATLearning<PBDataStructureFactory>();
-		PBSolverResolution solver = new PBSolverResolution(new FirstUIP(),
-				learning, new PBMaxClauseCardConstrDataStructure(),
+		PBSolverResolution solver = new PBSolverResolution(learning,
+				new PBMaxClauseCardConstrDataStructure(),
 				new VarOrderHeapObjective(), new MiniSATRestarts());
 		learning.setDataStructureFactory(solver.getDSFactory());
 		learning.setVarActivityListener(solver);
 		return solver;
 	}
 
-	public static PBSolverResolution newCompetPBResWLMixedConstraintsObjective() {
-		return newCompetPBResMixedConstraintsObjective(new CompetResolutionPBMixedWLClauseCardConstrDataStructure());
+	public static PBSolverResolution newCompetPBResWLMixedConstraintsObjectiveExpSimp() {
+		return newCompetPBResMixedConstraintsObjectiveExpSimp(new CompetResolutionPBMixedWLClauseCardConstrDataStructure());
 	}
 
-	public static PBSolverResolution newCompetPBResHTMixedConstraintsObjective() {
-		return newCompetPBResMixedConstraintsObjective(new CompetResolutionPBMixedHTClauseCardConstrDataStructure());
+	public static PBSolverResolution newCompetPBResHTMixedConstraintsObjectiveExpSimp() {
+		return newCompetPBResMixedConstraintsObjectiveExpSimp(new CompetResolutionPBMixedHTClauseCardConstrDataStructure());
 	}
 
-	public static PBSolverResolution newCompetPBResMixedConstraintsObjective(
+	public static PBSolverResolution newCompetPBResLongHTMixedConstraintsObjectiveExpSimp() {
+		return newCompetPBResMixedConstraintsObjectiveExpSimp(new CompetResolutionPBLongMixedHTClauseCardConstrDataStructure());
+	}
+
+	public static PBSolverResolution newCompetPBResLongWLMixedConstraintsObjectiveExpSimp() {
+		return newCompetPBResMixedConstraintsObjectiveExpSimp(new CompetResolutionPBLongMixedWLClauseCardConstrDataStructure());
+	}
+
+	public static PBSolverResolution newCompetMinPBResLongWLMixedConstraintsObjectiveExpSimp() {
+		return newCompetPBResMixedConstraintsObjectiveExpSimp(new CompetResolutionMinPBLongMixedWLClauseCardConstrDataStructure());
+	}
+
+	public static PBSolverResolution newCompetPBResMixedConstraintsObjectiveExpSimp(
 			PBDataStructureFactory dsf) {
 		MiniSATLearning<PBDataStructureFactory> learning = new MiniSATLearning<PBDataStructureFactory>();
-		PBSolverResolution solver = new PBSolverResolution(new FirstUIP(),
-				learning, dsf, new VarOrderHeapObjective(
-						new RSATPhaseSelectionStrategy()), new ArminRestarts());
+		PBSolverResolution solver = new PBSolverResolution(learning, dsf,
+				new VarOrderHeapObjective(new RSATPhaseSelectionStrategy()),
+				new ArminRestarts());
 		learning.setDataStructureFactory(solver.getDSFactory());
 		learning.setVarActivityListener(solver);
+		solver.setSimplifier(solver.EXPENSIVE_SIMPLIFICATION);
 		return solver;
 	}
 
@@ -293,9 +326,8 @@ public class SolverFactory extends ASolverFactory<IPBSolver> {
 		MiniSATLearning<PBDataStructureFactory> learning = new MiniSATLearning<PBDataStructureFactory>();
 		AbstractPBDataStructureFactory ds = new CompetResolutionPBMixedHTClauseCardConstrDataStructure();
 		ds.setNormalizer(AbstractPBDataStructureFactory.NO_COMPETITION);
-		PBSolverResolution solver = new PBSolverResolution(new FirstUIP(),
-				learning, ds, new VarOrderHeapObjective(),
-				new MiniSATRestarts());
+		PBSolverResolution solver = new PBSolverResolution(learning, ds,
+				new VarOrderHeapObjective(), new MiniSATRestarts());
 		learning.setDataStructureFactory(solver.getDSFactory());
 		learning.setVarActivityListener(solver);
 		return solver;
@@ -303,8 +335,7 @@ public class SolverFactory extends ASolverFactory<IPBSolver> {
 
 	public static PBSolverResolution newCompetPBResMinHTMixedConstraintsObjective() {
 		MiniSATLearning<PBDataStructureFactory> learning = new MiniSATLearning<PBDataStructureFactory>();
-		PBSolverResolution solver = new PBSolverResolution(new FirstUIP(),
-				learning,
+		PBSolverResolution solver = new PBSolverResolution(learning,
 				new CompetMinHTmixedClauseCardConstrDataStructureFactory(),
 				new VarOrderHeapObjective(), new MiniSATRestarts());
 		learning.setDataStructureFactory(solver.getDSFactory());
@@ -316,9 +347,8 @@ public class SolverFactory extends ASolverFactory<IPBSolver> {
 		MiniSATLearning<PBDataStructureFactory> learning = new MiniSATLearning<PBDataStructureFactory>();
 		AbstractPBDataStructureFactory ds = new CompetMinHTmixedClauseCardConstrDataStructureFactory();
 		ds.setNormalizer(AbstractPBDataStructureFactory.NO_COMPETITION);
-		PBSolverResolution solver = new PBSolverResolution(new FirstUIP(),
-				learning, ds, new VarOrderHeapObjective(),
-				new MiniSATRestarts());
+		PBSolverResolution solver = new PBSolverResolution(learning, ds,
+				new VarOrderHeapObjective(), new MiniSATRestarts());
 		learning.setDataStructureFactory(solver.getDSFactory());
 		learning.setVarActivityListener(solver);
 		return solver;
@@ -330,12 +360,6 @@ public class SolverFactory extends ASolverFactory<IPBSolver> {
 		return solver;
 	}
 
-	public static PBSolverResolution newCompetPBResWLMixedConstraintsObjectiveExpSimp() {
-		PBSolverResolution solver = newCompetPBResWLMixedConstraintsObjective();
-		solver.setSimplifier(solver.EXPENSIVE_SIMPLIFICATION);
-		return solver;
-	}
-
 	public static PBSolverResolution newPBResHTMixedConstraintsObjectiveExpSimp() {
 		PBSolverResolution solver = newPBResHTMixedConstraintsObjective();
 		solver.setSimplifier(solver.EXPENSIVE_SIMPLIFICATION);
@@ -357,7 +381,7 @@ public class SolverFactory extends ASolverFactory<IPBSolver> {
 	 */
 	public static PBSolverClause newPBCPMixedConstraintsReduceToClause() {
 		MiniSATLearning<PBDataStructureFactory> learning = new MiniSATLearning<PBDataStructureFactory>();
-		PBSolverClause solver = new PBSolverClause(new FirstUIP(), learning,
+		PBSolverClause solver = new PBSolverClause(learning,
 				new PBMaxClauseCardConstrDataStructure(), new VarOrderHeap());
 		learning.setDataStructureFactory(solver.getDSFactory());
 		learning.setVarActivityListener(solver);
@@ -373,8 +397,8 @@ public class SolverFactory extends ASolverFactory<IPBSolver> {
 	 */
 	public static PBSolverCautious newPBCPMixedConstraintsCautious(int bound) {
 		MiniSATLearning<PBDataStructureFactory> learning = new MiniSATLearning<PBDataStructureFactory>();
-		PBSolverCautious solver = new PBSolverCautious(new FirstUIP(),
-				learning, new PBMaxClauseCardConstrDataStructure(),
+		PBSolverCautious solver = new PBSolverCautious(learning,
+				new PBMaxClauseCardConstrDataStructure(),
 				new VarOrderHeapObjective(), bound);
 		learning.setDataStructureFactory(solver.getDSFactory());
 		learning.setVarActivityListener(solver);
@@ -394,7 +418,7 @@ public class SolverFactory extends ASolverFactory<IPBSolver> {
 	 */
 	public static PBSolverResCP newPBCPMixedConstraintsResCP(long bound) {
 		MiniSATLearning<PBDataStructureFactory> learning = new MiniSATLearning<PBDataStructureFactory>();
-		PBSolverResCP solver = new PBSolverResCP(new FirstUIP(), learning,
+		PBSolverResCP solver = new PBSolverResCP(learning,
 				new PBMaxClauseCardConstrDataStructure(),
 				new VarOrderHeapObjective(), bound);
 		learning.setDataStructureFactory(solver.getDSFactory());
@@ -416,8 +440,8 @@ public class SolverFactory extends ASolverFactory<IPBSolver> {
 	public static PBSolverWithImpliedClause newPBCPMixedConstrainsImplied() {
 		MiniSATLearning<PBDataStructureFactory> learning = new MiniSATLearning<PBDataStructureFactory>();
 		PBSolverWithImpliedClause solver = new PBSolverWithImpliedClause(
-				new FirstUIP(), learning,
-				new PBMaxClauseCardConstrDataStructure(), new VarOrderHeap());
+				learning, new PBMaxClauseCardConstrDataStructure(),
+				new VarOrderHeap());
 		learning.setDataStructureFactory(solver.getDSFactory());
 		learning.setVarActivityListener(solver);
 		return solver;
@@ -434,14 +458,6 @@ public class SolverFactory extends ASolverFactory<IPBSolver> {
 		return newPBCP(new PBMaxClauseAtLeastConstrDataStructure());
 	}
 
-	/**
-	 * @return MiniSAT with Counter-based pseudo boolean constraints and
-	 *         clauses, watched cardinalities, and constraint learning.
-	 */
-	public static PBSolverCP newMiniOPBCounterBasedClauseCardConstrMax() {
-		return newPBCP(new PBMaxCBClauseCardConstrDataStructure());
-	}
-
 	/**
 	 * @return MiniSAT with WL-based pseudo boolean constraints and clause
 	 *         learning.
@@ -468,8 +484,8 @@ public class SolverFactory extends ASolverFactory<IPBSolver> {
 
 	private static PBSolverResolution newPBRes(PBDataStructureFactory dsf) {
 		MiniSATLearning<PBDataStructureFactory> learning = new MiniSATLearning<PBDataStructureFactory>();
-		PBSolverResolution solver = new PBSolverResolution(new FirstUIP(),
-				learning, dsf, new VarOrderHeap(), new MiniSATRestarts());
+		PBSolverResolution solver = new PBSolverResolution(learning, dsf,
+				new VarOrderHeap(), new MiniSATRestarts());
 		learning.setDataStructureFactory(solver.getDSFactory());
 		learning.setVarActivityListener(solver);
 		return solver;
@@ -509,7 +525,7 @@ public class SolverFactory extends ASolverFactory<IPBSolver> {
 
 	private static PBSolverCP newPBCP(PBDataStructureFactory dsf, IOrder order) {
 		MiniSATLearning<PBDataStructureFactory> learning = new MiniSATLearning<PBDataStructureFactory>();
-		PBSolverCP solver = new PBSolverCP(new FirstUIP(), learning, dsf, order);
+		PBSolverCP solver = new PBSolverCP(learning, dsf, order);
 		learning.setDataStructureFactory(solver.getDSFactory());
 		learning.setVarActivityListener(solver);
 		solver.setRestartStrategy(new ArminRestarts());
@@ -531,6 +547,18 @@ public class SolverFactory extends ASolverFactory<IPBSolver> {
 		return newCompetPBCPMixedConstraintsObjective();
 	}
 
+	/**
+	 * Cutting Planes based solver. The inference during conflict analysis is
+	 * based on cutting planes instead of resolution as in a SAT solver.
+	 * 
+	 * @return the best available cutting planes based solver of the library.
+	 */
+	public static IPBSolver newCuttingPlanesAggressiveCleanup() {
+		PBSolverCP solver = newCompetPBCPMixedConstraintsObjective();
+		solver.setLearnedConstraintsDeletionStrategy(solver.fixedSize(100));
+		return solver;
+	}
+
 	/**
 	 * Resolution based solver (i.e. classic SAT solver able to handle generic
 	 * constraints. No specific inference mechanism.
@@ -538,7 +566,33 @@ public class SolverFactory extends ASolverFactory<IPBSolver> {
 	 * @return the best available resolution based solver of the library.
 	 */
 	public static IPBSolver newResolution() {
-		return newResolutionGlucose();
+		return newResolutionGlucoseExpSimp();
+	}
+
+	/**
+	 * Resolution and CuttingPlanes based solvers running in parallel. Does only
+	 * make sense if run on a computer with several cores.
+	 * 
+	 * @return a parallel solver using both resolution and cutting planes proof
+	 *         system.
+	 */
+	public static IPBSolver newBoth() {
+		return new ManyCorePB(newResolution(), newCuttingPlanes());
+	}
+
+	/**
+	 * Resolution based solver (i.e. classic SAT solver able to handle generic
+	 * constraints. No specific inference mechanism). Uses glucose based memory
+	 * management. The reason simplification is now disabled by default because
+	 * it slows down a lot when long PB or cardinality constraints are used.
+	 * 
+	 * @return the best available resolution based solver of the library.
+	 */
+	public static PBSolverResolution newResolutionGlucose() {
+		PBSolverResolution solver = newCompetPBResLongWLMixedConstraintsObjectiveExpSimp();
+		solver.setSimplifier(Solver.NO_SIMPLIFICATION);
+		solver.setLearnedConstraintsDeletionStrategy(solver.glucose);
+		return solver;
 	}
 
 	/**
@@ -548,9 +602,38 @@ public class SolverFactory extends ASolverFactory<IPBSolver> {
 	 * 
 	 * @return the best available resolution based solver of the library.
 	 */
-	public static IPBSolver newResolutionGlucose() {
+	public static PBSolverResolution newResolutionGlucoseSimpleSimp() {
+		PBSolverResolution solver = newResolutionGlucose();
+		solver.setSimplifier(solver.SIMPLE_SIMPLIFICATION);
+		return solver;
+	}
+
+	/**
+	 * Resolution based solver (i.e. classic SAT solver able to handle generic
+	 * constraints. No specific inference mechanism). Uses glucose based memory
+	 * management. It uses the expensive reason simplification. If the problem
+	 * contains long PB or cardinality constraints, it might be slowed down by
+	 * such treatment.
+	 * 
+	 * @return the best available resolution based solver of the library.
+	 */
+	public static PBSolverResolution newResolutionGlucoseExpSimp() {
+		PBSolverResolution solver = newResolutionGlucose();
+		solver.setSimplifier(solver.EXPENSIVE_SIMPLIFICATION);
+		return solver;
+	}
+
+	/**
+	 * Resolution based solver (i.e. classic SAT solver able to handle generic
+	 * constraints. No specific inference mechanism). Uses glucose based memory
+	 * management.
+	 * 
+	 * @return the best available resolution based solver of the library.
+	 */
+	public static IPBSolver newSimpleSimplification() {
 		PBSolverResolution solver = newCompetPBResWLMixedConstraintsObjectiveExpSimp();
 		solver.setLearnedConstraintsDeletionStrategy(solver.glucose);
+		solver.setSimplifier(solver.SIMPLE_SIMPLIFICATION);
 		return solver;
 	}
 
@@ -562,7 +645,7 @@ public class SolverFactory extends ASolverFactory<IPBSolver> {
 	 * @return the best available resolution based solver of the library.
 	 */
 	public static IPBSolver newResolutionSimpleRestarts() {
-		PBSolverResolution solver = newCompetPBResWLMixedConstraintsObjectiveExpSimp();
+		PBSolverResolution solver = newCompetPBResLongWLMixedConstraintsObjectiveExpSimp();
 		solver.setLearnedConstraintsDeletionStrategy(solver.glucose);
 		solver.setRestartStrategy(new MiniSATRestarts());
 		return solver;
@@ -577,7 +660,9 @@ public class SolverFactory extends ASolverFactory<IPBSolver> {
 	 * @return the best available resolution based solver of the library.
 	 */
 	public static IPBSolver newResolutionMaxMemory() {
-		return newCompetPBResWLMixedConstraintsObjectiveExpSimp();
+		PBSolverResolution solver = newCompetPBResLongWLMixedConstraintsObjectiveExpSimp();
+		solver.setLearnedConstraintsDeletionStrategy(solver.memory_based);
+		return solver;
 	}
 
 	/**
@@ -631,8 +716,7 @@ public class SolverFactory extends ASolverFactory<IPBSolver> {
 
 	public static IPBSolver newEclipseP2() {
 		MiniSATLearning<PBDataStructureFactory> learning = new MiniSATLearning<PBDataStructureFactory>();
-		PBSolverResolution solver = new PBSolverResolution(new FirstUIP(),
-				learning,
+		PBSolverResolution solver = new PBSolverResolution(learning,
 				new CompetResolutionPBMixedHTClauseCardConstrDataStructure(),
 				new VarOrderHeapObjective(new RSATPhaseSelectionStrategy()),
 				new ArminRestarts());
