@@ -65,8 +65,6 @@ public abstract class AbstractPBDataStructureFactory extends
 
 	public static final INormalizer FOR_COMPETITION = new INormalizer() {
 
-		private static final long serialVersionUID = 1L;
-
 		public PBContainer nice(IVecInt literals, IVec<BigInteger> coefs,
 				boolean moreThan, BigInteger degree, ILits voc)
 				throws ContradictionException {
@@ -99,8 +97,6 @@ public abstract class AbstractPBDataStructureFactory extends
 
 	public static final INormalizer NO_COMPETITION = new INormalizer() {
 
-		private static final long serialVersionUID = 1L;
-
 		public PBContainer nice(IVecInt literals, IVec<BigInteger> coefs,
 				boolean moreThan, BigInteger degree, ILits voc)
 				throws ContradictionException {
@@ -143,8 +139,13 @@ public abstract class AbstractPBDataStructureFactory extends
 
 	public Constr createClause(IVecInt literals) throws ContradictionException {
 		IVecInt v = Clauses.sanityCheck(literals, getVocabulary(), solver);
-		if (v == null)
+		if (v == null) {
+			// tautological clause
 			return null;
+		}
+		if (v.size() == 1) {
+			return new UnitClause(v.last());
+		}
 		if (v.size() == 2) {
 			return OriginalBinaryClause.brandNewClause(solver, getVocabulary(),
 					v);
