@@ -27,39 +27,19 @@
  *******************************************************************************/
 package org.sat4j.pb.constraints;
 
-import java.math.BigInteger;
-
-import org.sat4j.core.Vec;
-import org.sat4j.core.VecInt;
-import org.sat4j.minisat.core.Constr;
-import org.sat4j.pb.constraints.pb.AtLeastPB;
-import org.sat4j.pb.constraints.pb.IDataStructurePB;
-import org.sat4j.pb.constraints.pb.PBConstr;
-import org.sat4j.specs.ContradictionException;
-import org.sat4j.specs.IVec;
-import org.sat4j.specs.IVecInt;
 
 public class PuebloPBMinClauseAtLeastConstrDataStructure extends
-		PuebloPBMinClauseCardConstrDataStructure {
+		AbstractPBClauseCardConstrDataStructure {
 
 	/**
      * 
      */
 	private static final long serialVersionUID = 1L;
 
-	@Override
-	protected PBConstr constructCard(IVecInt theLits, int degree)
-			throws ContradictionException {
-		return AtLeastPB.atLeastNew(solver, getVocabulary(), theLits, degree);
-	}
-
-	@Override
-	protected Constr constructLearntCard(IDataStructurePB dspb) {
-		IVecInt resLits = new VecInt();
-		IVec<BigInteger> resCoefs = new Vec<BigInteger>();
-		dspb.buildConstraintFromConflict(resLits, resCoefs);
-		return AtLeastPB.atLeastNew(getVocabulary(), resLits, dspb.getDegree()
-				.intValue());
+	public PuebloPBMinClauseAtLeastConstrDataStructure() {
+		super(new UnitBinaryHTClausePBConstructor(),
+				new AtLeastCardPBConstructor(),
+				new PuebloMinWatchPBConstructor());
 	}
 
 }
