@@ -28,7 +28,6 @@
 package org.sat4j.pb.core;
 
 import org.sat4j.core.Vec;
-import org.sat4j.minisat.core.AssertingClauseGenerator;
 import org.sat4j.minisat.core.Constr;
 import org.sat4j.minisat.core.IOrder;
 import org.sat4j.minisat.core.LearningStrategy;
@@ -40,6 +39,7 @@ import org.sat4j.pb.constraints.pb.ConflictMap;
 import org.sat4j.pb.constraints.pb.IConflict;
 import org.sat4j.pb.constraints.pb.PBConstr;
 import org.sat4j.specs.IVec;
+import org.sat4j.specs.TimeoutException;
 
 /**
  * @author parrain To change the template for this generated type comment go to
@@ -54,40 +54,40 @@ public class PBSolverCP extends PBSolver {
 	 * @param learner
 	 * @param dsf
 	 */
-	public PBSolverCP(AssertingClauseGenerator acg,
-			LearningStrategy<PBDataStructureFactory> learner,
+	public PBSolverCP(LearningStrategy<PBDataStructureFactory> learner,
 			PBDataStructureFactory dsf, IOrder order) {
-		super(acg, learner, dsf, new SearchParams(1.5, 100), order,
+		super(learner, dsf, new SearchParams(1.5, 100), order,
 				new MiniSATRestarts());
 	}
 
-	public PBSolverCP(AssertingClauseGenerator acg,
-			LearningStrategy<PBDataStructureFactory> learner,
+	public PBSolverCP(LearningStrategy<PBDataStructureFactory> learner,
 			PBDataStructureFactory dsf, SearchParams params, IOrder order,
 			RestartStrategy restarter) {
-		super(acg, learner, dsf, params, order, restarter);
+		super(learner, dsf, params, order, restarter);
 	}
 
-	public PBSolverCP(AssertingClauseGenerator acg,
-			LearningStrategy<PBDataStructureFactory> learner,
+	public PBSolverCP(LearningStrategy<PBDataStructureFactory> learner,
 			PBDataStructureFactory dsf, SearchParams params, IOrder order) {
-		super(acg, learner, dsf, params, order, new MiniSATRestarts());
+		super(learner, dsf, params, order, new MiniSATRestarts());
 	}
 
 	@Override
-	public void analyze(Constr myconfl, Pair results) {
+	public void analyze(Constr myconfl, Pair results) throws TimeoutException {
 		if (someCriteria())
 			analyzeCP(myconfl, results);
 		else
 			super.analyze(myconfl, results);
 	}
 
-	public void analyzeCP(Constr myconfl, Pair results) {
+	public void analyzeCP(Constr myconfl, Pair results) throws TimeoutException {
 		int litImplied = trail.last();
 		int currentLevel = voc.getLevel(litImplied);
 		IConflict confl = chooseConflict((PBConstr) myconfl, currentLevel);
 		assert confl.slackConflict().signum() < 0;
 		while (!confl.isAssertive(currentLevel)) {
+			if (!undertimeout) {
+				throw new TimeoutException();
+			}
 			PBConstr constraint = (PBConstr) voc.getReason(litImplied);
 			// result of the resolution is in the conflict (confl)
 			confl.resolve(constraint, litImplied, this);
