@@ -39,7 +39,8 @@ import org.sat4j.pb.ObjectiveFunction;
 import org.sat4j.specs.IVec;
 import org.sat4j.specs.IVecInt;
 
-public class VarOrderHeapObjective extends VarOrderHeap {
+public class VarOrderHeapObjective extends VarOrderHeap implements
+		IOrderObjective {
 
 	/**
      * 
