@@ -53,6 +53,8 @@ package org.sat4j.pb.reader;
 
 import java.io.BufferedReader;
 import java.io.IOException;
+import java.io.InputStream;
+import java.io.InputStreamReader;
 import java.io.LineNumberReader;
 import java.io.PrintWriter;
 import java.io.Serializable;
@@ -168,11 +170,13 @@ public class OPBReader2005 extends Reader implements Serializable {
 		assert !(coeffs.size() == 0);
 		assert lits.size() == coeffs.size();
 
-		if ("<=".equals(operator) || "=".equals(operator)) {
-			solver.addPseudoBoolean(lits, coeffs, false, d);
-		}
-		if (">=".equals(operator) || "=".equals(operator)) {
-			solver.addPseudoBoolean(lits, coeffs, true, d);
+		if ("=".equals(operator)) {
+			solver.addExactly(lits, coeffs, d);
+		} else if ("<=".equals(operator)) {
+			solver.addAtMost(lits, coeffs, d);
+		} else {
+			assert ">=".equals(operator);
+			solver.addAtLeast(lits, coeffs, d);
 		}
 		nbConstraintsRead++;
 	}
@@ -691,9 +695,9 @@ public class OPBReader2005 extends Reader implements Serializable {
 
 			if (e instanceof ParseFormatException) {
 				message = e.getMessage().substring(
-						"DIMACS Format error: ".length());
+						ParseFormatException.PARSING_ERROR.length());
 			} else {
-				message = e.getMessage();
+				message = e.toString();
 			}
 			throw new ParseFormatException(" line "
 					+ (input.getLineNumber() + 1) + ", " + message);
@@ -743,4 +747,9 @@ public class OPBReader2005 extends Reader implements Serializable {
 		return null;
 	}
 
+	@Override
+	public IProblem parseInstance(final InputStream in)
+			throws ParseFormatException, ContradictionException, IOException {
+		return parseInstance(new InputStreamReader(in));
+	}
 }
