@@ -20,6 +20,7 @@
 package org.sat4j.pb.tools;
 
 import java.math.BigInteger;
+import java.util.ArrayList;
 import java.util.Collection;
 import java.util.HashMap;
 import java.util.Iterator;
@@ -51,7 +52,7 @@ import org.sat4j.tools.GateTranslator;
  */
 public class DependencyHelper<T, C> {
 
-	public final INegator NO_NEGATION = new INegator() {
+	public static final INegator NO_NEGATION = new INegator() {
 
 		public boolean isNegated(Object thing) {
 			return false;
@@ -103,8 +104,8 @@ public class DependencyHelper<T, C> {
 	private IVecInt objLiterals;
 	private IVec<BigInteger> objCoefs;
 
-	public boolean explanationEnabled = true;
-	public boolean canonicalOptFunction = true;
+	private final boolean explanationEnabled;
+	private final boolean canonicalOptFunction;
 
 	/**
 	 * 
@@ -155,6 +156,7 @@ public class DependencyHelper<T, C> {
 			this.solver = solver;
 		}
 		this.gator = new GateTranslator(this.solver);
+		this.explanationEnabled = explanationEnabled;
 		canonicalOptFunction = canonicalOptFunctionEnabled;
 	}
 
@@ -169,7 +171,7 @@ public class DependencyHelper<T, C> {
 	 *            a domain object
 	 * @return the dimacs variable (an integer) representing that domain object.
 	 */
-	int getIntValue(T thing) {
+	protected int getIntValue(T thing) {
 		return getIntValue(thing, true);
 	}
 
@@ -184,7 +186,7 @@ public class DependencyHelper<T, C> {
 	 *            IllegalArgumentException if the object is unknown.
 	 * @return the dimacs variable (an integer) representing that domain object.
 	 */
-	int getIntValue(T thing, boolean create) {
+	protected int getIntValue(T thing, boolean create) {
 		T myThing;
 		boolean negated = negator.isNegated(thing);
 		if (negated) {
@@ -212,11 +214,16 @@ public class DependencyHelper<T, C> {
 	/**
 	 * Retrieve the solution found.
 	 * 
+	 * Note that this method returns a Sat4j specific data structure (IVec).
+	 * People willing to retrieve a more common data structure should use
+	 * {@link #getASolution()} instead.
+	 * 
 	 * THAT METHOD IS EXPECTED TO BE CALLED IF hasASolution() RETURNS TRUE.
 	 * 
 	 * @return the domain object that must be satisfied to satisfy the
 	 *         constraints entered in the solver.
 	 * @see {@link #hasASolution()}
+	 * @see {@link #getASolution()}
 	 */
 	public IVec<T> getSolution() {
 		int[] model = solver.model();
@@ -231,8 +238,35 @@ public class DependencyHelper<T, C> {
 		return toInstall;
 	}
 
+	/**
+	 * Retrieve a collection of objects satisfying the constraints.
+	 * 
+	 * It behaves basically the same as {@link #getSolution()} but returns a
+	 * common Collection instead of a Sat4j specific IVec.
+	 * 
+	 * THAT METHOD IS EXPECTED TO BE CALLED IF hasASolution() RETURNS TRUE.
+	 * 
+	 * @return the domain object that must be satisfied to satisfy the
+	 *         constraints entered in the solver.
+	 * @see {@link #hasASolution()}
+	 * @see {@link #getSolution()}
+	 * @since 2.3.1
+	 */
+	public Collection<T> getASolution() {
+		int[] model = solver.model();
+		Collection<T> toInstall = new ArrayList<T>();
+		if (model != null) {
+			for (int i : model) {
+				if (i > 0) {
+					toInstall.add(mapToDomain.get(i));
+				}
+			}
+		}
+		return toInstall;
+	}
+
 	public BigInteger getSolutionCost() {
-		return objFunction.calculateDegree(solver.model());
+		return objFunction.calculateDegree(solver);
 	}
 
 	/**
@@ -517,11 +551,9 @@ public class DependencyHelper<T, C> {
 		}
 		IConstr[] constrs = gator.iff(getIntValue(thing), literals);
 		for (IConstr constr : constrs) {
-			if (constr == null) {
-				throw new IllegalStateException(
-						"Constraints are not supposed to be null when using the helper");
+			if (constr != null) {
+				descs.put(constr, name);
 			}
-			descs.put(constr, name);
 		}
 	}
 
@@ -542,11 +574,9 @@ public class DependencyHelper<T, C> {
 		}
 		IConstr[] constrs = gator.and(getIntValue(thing), literals);
 		for (IConstr constr : constrs) {
-			if (constr == null) {
-				throw new IllegalStateException(
-						"Constraints are not supposed to be null when using the helper");
+			if (constr != null) {
+				descs.put(constr, name);
 			}
-			descs.put(constr, name);
 		}
 	}
 
@@ -567,11 +597,9 @@ public class DependencyHelper<T, C> {
 		}
 		IConstr[] constrs = gator.or(getIntValue(thing), literals);
 		for (IConstr constr : constrs) {
-			if (constr == null) {
-				throw new IllegalStateException(
-						"Constraints are not supposed to be null when using the helper");
+			if (constr != null) {
+				descs.put(constr, name);
 			}
-			descs.put(constr, name);
 		}
 	}
 
@@ -592,11 +620,9 @@ public class DependencyHelper<T, C> {
 		}
 		IConstr[] constrs = gator.halfOr(getIntValue(thing), literals);
 		for (IConstr constr : constrs) {
-			if (constr == null) {
-				throw new IllegalStateException(
-						"Constraints are not supposed to be null when using the helper");
+			if (constr != null) {
+				descs.put(constr, name);
 			}
-			descs.put(constr, name);
 		}
 	}
 
@@ -615,11 +641,9 @@ public class DependencyHelper<T, C> {
 				getIntValue(conditionThing), getIntValue(thenThing),
 				getIntValue(elseThing));
 		for (IConstr constr : constrs) {
-			if (constr == null) {
-				throw new IllegalStateException(
-						"Constraints are not supposed to be null when using the helper");
+			if (constr != null) {
+				descs.put(constr, name);
 			}
-			descs.put(constr, name);
 		}
 	}
 
@@ -796,6 +820,24 @@ public class DependencyHelper<T, C> {
 	 * @return the IPBSolver enclosed in the helper.
 	 */
 	public IPBSolver getSolver() {
+		if (explanationEnabled)
+			return xplain.decorated();
 		return solver;
 	}
+
+	/**
+	 * Reset the state of the helper (mapping, objective function, etc).
+	 * 
+	 * @since 2.3.1
+	 */
+	public void reset() {
+		mapToDimacs.clear();
+		mapToDomain.clear();
+		descs.clear();
+		solver.reset();
+		if (objLiterals != null) {
+			objLiterals.clear();
+			objCoefs.clear();
+		}
+	}
 }
